from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.universe import quota_pb2 as _quota_pb2
from eolymp.universe import space_pb2 as _space_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateSpaceInput(_message.Message):
    __slots__ = ["space"]
    SPACE_FIELD_NUMBER: _ClassVar[int]
    space: _space_pb2.Space
    def __init__(self, space: _Optional[_Union[_space_pb2.Space, _Mapping]] = ...) -> None: ...

class CreateSpaceOutput(_message.Message):
    __slots__ = ["space_id"]
    SPACE_ID_FIELD_NUMBER: _ClassVar[int]
    space_id: str
    def __init__(self, space_id: _Optional[str] = ...) -> None: ...

class DeleteSpaceInput(_message.Message):
    __slots__ = ["space_id"]
    SPACE_ID_FIELD_NUMBER: _ClassVar[int]
    space_id: str
    def __init__(self, space_id: _Optional[str] = ...) -> None: ...

class DeleteSpaceOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeQuotaInput(_message.Message):
    __slots__ = ["space_id"]
    SPACE_ID_FIELD_NUMBER: _ClassVar[int]
    space_id: str
    def __init__(self, space_id: _Optional[str] = ...) -> None: ...

class DescribeQuotaOutput(_message.Message):
    __slots__ = ["quota"]
    QUOTA_FIELD_NUMBER: _ClassVar[int]
    quota: _quota_pb2.Quota
    def __init__(self, quota: _Optional[_Union[_quota_pb2.Quota, _Mapping]] = ...) -> None: ...

class DescribeSpaceInput(_message.Message):
    __slots__ = ["extra", "space_id"]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    SPACE_ID_FIELD_NUMBER: _ClassVar[int]
    extra: _containers.RepeatedScalarFieldContainer[_space_pb2.Space.Extra]
    space_id: str
    def __init__(self, space_id: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_space_pb2.Space.Extra, str]]] = ...) -> None: ...

class DescribeSpaceOutput(_message.Message):
    __slots__ = ["space"]
    SPACE_FIELD_NUMBER: _ClassVar[int]
    space: _space_pb2.Space
    def __init__(self, space: _Optional[_Union[_space_pb2.Space, _Mapping]] = ...) -> None: ...

class ListSpacesInput(_message.Message):
    __slots__ = ["extra", "filters", "offset", "size"]
    class Filter(_message.Message):
        __slots__ = ["id", "key", "name", "own", "query"]
        ID_FIELD_NUMBER: _ClassVar[int]
        KEY_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        OWN_FIELD_NUMBER: _ClassVar[int]
        QUERY_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        key: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        name: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        own: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        query: str
        def __init__(self, query: _Optional[str] = ..., id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., key: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., name: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., own: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ...) -> None: ...
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    extra: _containers.RepeatedScalarFieldContainer[_space_pb2.Space.Extra]
    filters: ListSpacesInput.Filter
    offset: int
    size: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListSpacesInput.Filter, _Mapping]] = ..., extra: _Optional[_Iterable[_Union[_space_pb2.Space.Extra, str]]] = ...) -> None: ...

class ListSpacesOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_space_pb2.Space]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_space_pb2.Space, _Mapping]]] = ...) -> None: ...

class LookupSpaceInput(_message.Message):
    __slots__ = ["extra", "key"]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    extra: _containers.RepeatedScalarFieldContainer[_space_pb2.Space.Extra]
    key: str
    def __init__(self, key: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_space_pb2.Space.Extra, str]]] = ...) -> None: ...

class LookupSpaceOutput(_message.Message):
    __slots__ = ["space"]
    SPACE_FIELD_NUMBER: _ClassVar[int]
    space: _space_pb2.Space
    def __init__(self, space: _Optional[_Union[_space_pb2.Space, _Mapping]] = ...) -> None: ...

class UpdateQuotaInput(_message.Message):
    __slots__ = ["quota", "space_id"]
    QUOTA_FIELD_NUMBER: _ClassVar[int]
    SPACE_ID_FIELD_NUMBER: _ClassVar[int]
    quota: _quota_pb2.Quota
    space_id: str
    def __init__(self, space_id: _Optional[str] = ..., quota: _Optional[_Union[_quota_pb2.Quota, _Mapping]] = ...) -> None: ...

class UpdateQuotaOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateSpaceInput(_message.Message):
    __slots__ = ["patch", "space", "space_id"]
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ALL: UpdateSpaceInput.Patch
    IMAGE: UpdateSpaceInput.Patch
    KEY: UpdateSpaceInput.Patch
    NAME: UpdateSpaceInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    SPACE_FIELD_NUMBER: _ClassVar[int]
    SPACE_ID_FIELD_NUMBER: _ClassVar[int]
    TYPE: UpdateSpaceInput.Patch
    VISIBILITY: UpdateSpaceInput.Patch
    patch: _containers.RepeatedScalarFieldContainer[UpdateSpaceInput.Patch]
    space: _space_pb2.Space
    space_id: str
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateSpaceInput.Patch, str]]] = ..., space_id: _Optional[str] = ..., space: _Optional[_Union[_space_pb2.Space, _Mapping]] = ...) -> None: ...

class UpdateSpaceOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Statement(_message.Message):
    __slots__ = ["author", "content", "download_link", "id", "locale", "source", "title"]
    AUTHOR_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    DOWNLOAD_LINK_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    author: str
    content: _content_pb2.Content
    download_link: str
    id: str
    locale: str
    source: str
    title: str
    def __init__(self, id: _Optional[str] = ..., locale: _Optional[str] = ..., title: _Optional[str] = ..., content: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., download_link: _Optional[str] = ..., author: _Optional[str] = ..., source: _Optional[str] = ...) -> None: ...



from eolymp.content import fragment_pb2 as _fragment_pb2
from eolymp.content import variant_pb2 as _variant_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FragmentChangedEvent(_message.Message):
    __slots__ = ["after", "before"]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    after: _fragment_pb2.Fragment
    before: _fragment_pb2.Fragment
    def __init__(self, before: _Optional[_Union[_fragment_pb2.Fragment, _Mapping]] = ..., after: _Optional[_Union[_fragment_pb2.Fragment, _Mapping]] = ...) -> None: ...

class VariantChangedEvent(_message.Message):
    __slots__ = ["after", "before", "fragment"]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    FRAGMENT_FIELD_NUMBER: _ClassVar[int]
    after: _variant_pb2.Variant
    before: _variant_pb2.Variant
    fragment: _fragment_pb2.Fragment
    def __init__(self, fragment: _Optional[_Union[_fragment_pb2.Fragment, _Mapping]] = ..., before: _Optional[_Union[_variant_pb2.Variant, _Mapping]] = ..., after: _Optional[_Union[_variant_pb2.Variant, _Mapping]] = ...) -> None: ...



from eolymp.acl import policy_pb2 as _policy_pb2
from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CopyPoliciesInput(_message.Message):
    __slots__ = ["dst_principal", "dst_resource", "src_principal", "src_resource"]
    DST_PRINCIPAL_FIELD_NUMBER: _ClassVar[int]
    DST_RESOURCE_FIELD_NUMBER: _ClassVar[int]
    SRC_PRINCIPAL_FIELD_NUMBER: _ClassVar[int]
    SRC_RESOURCE_FIELD_NUMBER: _ClassVar[int]
    dst_principal: str
    dst_resource: str
    src_principal: str
    src_resource: str
    def __init__(self, src_principal: _Optional[str] = ..., dst_principal: _Optional[str] = ..., src_resource: _Optional[str] = ..., dst_resource: _Optional[str] = ...) -> None: ...

class CopyPoliciesOutput(_message.Message):
    __slots__ = ["copies_count"]
    COPIES_COUNT_FIELD_NUMBER: _ClassVar[int]
    copies_count: int
    def __init__(self, copies_count: _Optional[int] = ...) -> None: ...

class CreatePolicyInput(_message.Message):
    __slots__ = ["policy"]
    POLICY_FIELD_NUMBER: _ClassVar[int]
    policy: _policy_pb2.Policy
    def __init__(self, policy: _Optional[_Union[_policy_pb2.Policy, _Mapping]] = ...) -> None: ...

class CreatePolicyOutput(_message.Message):
    __slots__ = ["policy_id"]
    POLICY_ID_FIELD_NUMBER: _ClassVar[int]
    policy_id: str
    def __init__(self, policy_id: _Optional[str] = ...) -> None: ...

class DeletePolicyInput(_message.Message):
    __slots__ = ["policy_id"]
    POLICY_ID_FIELD_NUMBER: _ClassVar[int]
    policy_id: str
    def __init__(self, policy_id: _Optional[str] = ...) -> None: ...

class DeletePolicyOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribePolicyInput(_message.Message):
    __slots__ = ["policy_id"]
    POLICY_ID_FIELD_NUMBER: _ClassVar[int]
    policy_id: str
    def __init__(self, policy_id: _Optional[str] = ...) -> None: ...

class DescribePolicyOutput(_message.Message):
    __slots__ = ["policy"]
    POLICY_FIELD_NUMBER: _ClassVar[int]
    policy: _policy_pb2.Policy
    def __init__(self, policy: _Optional[_Union[_policy_pb2.Policy, _Mapping]] = ...) -> None: ...

class ListPoliciesInput(_message.Message):
    __slots__ = ["filters", "offset", "size"]
    class Filter(_message.Message):
        __slots__ = ["id", "name", "principal", "query", "resource"]
        ID_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        PRINCIPAL_FIELD_NUMBER: _ClassVar[int]
        QUERY_FIELD_NUMBER: _ClassVar[int]
        RESOURCE_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        name: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        principal: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        query: str
        resource: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, query: _Optional[str] = ..., id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., principal: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., name: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., resource: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    filters: ListPoliciesInput.Filter
    offset: int
    size: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListPoliciesInput.Filter, _Mapping]] = ...) -> None: ...

class ListPoliciesOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_policy_pb2.Policy]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_policy_pb2.Policy, _Mapping]]] = ...) -> None: ...

class UpdatePolicyInput(_message.Message):
    __slots__ = ["patch", "policy", "policy_id"]
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ALL: UpdatePolicyInput.Patch
    ALLOWS: UpdatePolicyInput.Patch
    NAME: UpdatePolicyInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    POLICY_FIELD_NUMBER: _ClassVar[int]
    POLICY_ID_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[UpdatePolicyInput.Patch]
    policy: _policy_pb2.Policy
    policy_id: str
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdatePolicyInput.Patch, str]]] = ..., policy_id: _Optional[str] = ..., policy: _Optional[_Union[_policy_pb2.Policy, _Mapping]] = ...) -> None: ...

class UpdatePolicyOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/notify/notification.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/notify/notification.proto\x12\reolymp.notify\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb5\x02\n\x0cNotification\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04read\x18\x02 \x01(\x08\x12\r\n\x05topic\x18\n \x01(\t\x12?\n\nparameters\x18\x0b \x03(\x0b\x32+.eolymp.notify.Notification.ParametersEntry\x12.\n\ncreated_at\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07sent_at\x18\x16 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07read_at\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42/Z-github.com/eolymp/go-sdk/eolymp/notify;notifyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.notify.notification_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/notify;notify'
  _NOTIFICATION_PARAMETERSENTRY._options = None
  _NOTIFICATION_PARAMETERSENTRY._serialized_options = b'8\001'
  _NOTIFICATION._serialized_start=85
  _NOTIFICATION._serialized_end=394
  _NOTIFICATION_PARAMETERSENTRY._serialized_start=345
  _NOTIFICATION_PARAMETERSENTRY._serialized_end=394
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Job(_message.Message):
    __slots__ = ["complete_at", "created_at", "id", "inputs", "logs", "outputs", "progress", "progress_at", "started_at", "status", "total", "type"]
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class InputsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    class OutputsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    COMPLETE: Job.Status
    COMPLETE_AT_FIELD_NUMBER: _ClassVar[int]
    CREATED: Job.Status
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    ERROR: Job.Status
    ID_FIELD_NUMBER: _ClassVar[int]
    INPUTS_FIELD_NUMBER: _ClassVar[int]
    LOGS_FIELD_NUMBER: _ClassVar[int]
    OUTPUTS_FIELD_NUMBER: _ClassVar[int]
    PROGRESS_AT_FIELD_NUMBER: _ClassVar[int]
    PROGRESS_FIELD_NUMBER: _ClassVar[int]
    STARTED: Job.Status
    STARTED_AT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    UNKNOWN: Job.Status
    complete_at: _timestamp_pb2.Timestamp
    created_at: _timestamp_pb2.Timestamp
    id: str
    inputs: _containers.ScalarMap[str, str]
    logs: str
    outputs: _containers.ScalarMap[str, str]
    progress: int
    progress_at: _timestamp_pb2.Timestamp
    started_at: _timestamp_pb2.Timestamp
    status: Job.Status
    total: int
    type: str
    def __init__(self, id: _Optional[str] = ..., type: _Optional[str] = ..., inputs: _Optional[_Mapping[str, str]] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., started_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., progress_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., complete_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., progress: _Optional[int] = ..., total: _Optional[int] = ..., status: _Optional[_Union[Job.Status, str]] = ..., outputs: _Optional[_Mapping[str, str]] = ..., logs: _Optional[str] = ...) -> None: ...



import time
import urllib.parse

import requests

from google.protobuf import json_format


class HttpClient:
    def __init__(self, token: str = "", headers: dict = None, retry: int = 5):
        self._token = token
        self._headers = headers if headers is not None else {}
        self._retry = retry if retry > 1 else 1

    def request(self, url: str, method: str, request_data: object, response_symbol: str, **kwargs):
        headers = self._headers
        headers["content-type"] = "application/json"

        if self._token:
            headers["authorization"] = "Bearer " + self._token

        wait = 1
        for t in range(0, self._retry):
            data = json_format.MessageToJson(request_data)
            if method == "GET":
                query = ("?q=" + urllib.parse.quote(data)) if data != "{}" else ""
                resp = requests.request(url=url+query, method=method, headers=headers, **kwargs)
            else:
                resp = requests.request(url=url, method=method, data=data, headers=headers, **kwargs)

            if resp.status_code == 429:
                time.sleep(wait)
                wait = wait + 1
                continue

            if resp.status_code == 200:
                response = response_symbol()
                json_format.Parse(resp.content, response, ignore_unknown_fields=True)
                return response
            else:
                raise Exception("Got non-200 response: {}".format(resp.status_code))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/student_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.course import assignment_pb2 as eolymp_dot_course_dot_assignment__pb2
from eolymp.course import material_pb2 as eolymp_dot_course_dot_material__pb2
from eolymp.course import module_pb2 as eolymp_dot_course_dot_module__pb2
from eolymp.course import student_pb2 as eolymp_dot_course_dot_student__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/course/student_service.proto\x12\reolymp.course\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1e\x65olymp/course/assignment.proto\x1a\x1c\x65olymp/course/material.proto\x1a\x1a\x65olymp/course/module.proto\x1a\x1b\x65olymp/course/student.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"=\n\x12\x43reateStudentInput\x12\'\n\x07student\x18\x01 \x01(\x0b\x32\x16.eolymp.course.Student\")\n\x13\x43reateStudentOutput\x12\x12\n\nstudent_id\x18\x02 \x01(\t\"\xb8\x01\n\x12UpdateStudentInput\x12\x36\n\x05patch\x18\x01 \x03(\x0e\x32\'.eolymp.course.UpdateStudentInput.Patch\x12\x11\n\tmember_id\x18\x02 \x01(\t\x12\'\n\x07student\x18\x03 \x01(\x0b\x32\x16.eolymp.course.Student\".\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x0c\n\x08INACTIVE\x10\x01\x12\x0e\n\nASSIGN_ALL\x10\x02\"\x15\n\x13UpdateStudentOutput\"\'\n\x12\x44\x65leteStudentInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\"\x15\n\x13\x44\x65leteStudentOutput\"W\n\x14\x44\x65scribeStudentInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12,\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1c.eolymp.course.Student.Extra\"@\n\x15\x44\x65scribeStudentOutput\x12\'\n\x07student\x18\x01 \x01(\x0b\x32\x16.eolymp.course.Student\"\xd1\x03\n\x11ListStudentsInput\x12\r\n\x05\x61\x66ter\x18\x0c \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x38\n\x07\x66ilters\x18( \x01(\x0b\x32\'.eolymp.course.ListStudentsInput.Filter\x12\x37\n\x04sort\x18\x32 \x01(\x0e\x32).eolymp.course.ListStudentsInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12,\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1c.eolymp.course.Student.Extra\x1a\xa8\x01\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\n \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\x0b \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x08group_id\x18\x0c \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"\x17\n\x08Sortable\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\"~\n\x12ListStudentsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.course.Student\x12\x18\n\x10next_page_cursor\x18\x03 \x01(\t\x12\x18\n\x10prev_page_cursor\x18\x04 \x01(\t\"T\n\x11WatchStudentInput\x12\x11\n\tmember_id\x18\x02 \x01(\t\x12,\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1c.eolymp.course.Student.Extra\"=\n\x12WatchStudentOutput\x12\'\n\x07student\x18\x01 \x01(\x0b\x32\x16.eolymp.course.Student\"\x11\n\x0fJoinCourseInput\"\x12\n\x10JoinCourseOutput\"C\n\x13\x44\x65scribeViewerInput\x12,\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1c.eolymp.course.Student.Extra\"?\n\x14\x44\x65scribeViewerOutput\x12\'\n\x07student\x18\x01 \x01(\x0b\x32\x16.eolymp.course.Student\"\x8a\x02\n\x1bListStudentAssignmentsInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x42\n\x07\x66ilters\x18( \x01(\x0b\x32\x31.eolymp.course.ListStudentAssignmentsInput.Filter\x1av\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\n \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmodule_id\x18\x0b \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"W\n\x1cListStudentAssignmentsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.course.Assignment\"\xcd\x01\n\x1cUpdateStudentAssignmentInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x11\n\tmodule_id\x18\x02 \x01(\t\x12/\n\x0bstart_after\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0f\x63omplete_before\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x64uration\x18\r \x01(\r\x12\x0f\n\x07upsolve\x18\x1e \x01(\x08\"\x1f\n\x1dUpdateStudentAssignmentOutput\"D\n\x1c\x44\x65leteStudentAssignmentInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x11\n\tmodule_id\x18\x02 \x01(\t\"\x1f\n\x1d\x44\x65leteStudentAssignmentOutput\"+\n\x16ListStudentGradesInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\"H\n\x17ListStudentGradesOutput\x12-\n\x05items\x18\x01 \x03(\x0b\x32\x1e.eolymp.course.Module.Progress\"=\n\x15ListModuleGradesInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x11\n\tmodule_id\x18\x02 \x01(\t\"I\n\x16ListModuleGradesOutput\x12/\n\x05items\x18\x01 \x03(\x0b\x32 .eolymp.course.Material.Progress2\x8b\x11\n\x0eStudentService\x12\x93\x01\n\rCreateStudent\x12!.eolymp.course.CreateStudentInput\x1a\".eolymp.course.CreateStudentOutput\";\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x0b\"\t/students\x12\x9f\x01\n\rUpdateStudent\x12!.eolymp.course.UpdateStudentInput\x1a\".eolymp.course.UpdateStudentOutput\"G\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x17\"\x15/students/{member_id}\x12\x9f\x01\n\rDeleteStudent\x12!.eolymp.course.DeleteStudentInput\x1a\".eolymp.course.DeleteStudentOutput\"G\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x17*\x15/students/{member_id}\x12\xa4\x01\n\x0f\x44\x65scribeStudent\x12#.eolymp.course.DescribeStudentInput\x1a$.eolymp.course.DescribeStudentOutput\"F\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x17\x12\x15/students/{member_id}\x12\x8f\x01\n\x0cListStudents\x12 .eolymp.course.ListStudentsInput\x1a!.eolymp.course.ListStudentsOutput\":\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0b\x12\t/students\x12q\n\x0cWatchStudent\x12 .eolymp.course.WatchStudentInput\x1a!.eolymp.course.WatchStudentOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read0\x01\x12\x85\x01\n\nJoinCourse\x12\x1e.eolymp.course.JoinCourseInput\x1a\x1f.eolymp.course.JoinCourseOutput\"6\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x07\"\x05/join\x12\x9b\x01\n\x0e\x44\x65scribeViewer\x12\".eolymp.course.DescribeViewerInput\x1a#.eolymp.course.DescribeViewerOutput\"@\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x11\x12\x0f/viewer/student\x12\xc5\x01\n\x16ListStudentAssignments\x12*.eolymp.course.ListStudentAssignmentsInput\x1a+.eolymp.course.ListStudentAssignmentsOutput\"R\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02#\x12!/students/{member_id}/assignments\x12\xc8\x01\n\x17UpdateStudentAssignment\x12+.eolymp.course.UpdateStudentAssignmentInput\x1a,.eolymp.course.UpdateStudentAssignmentOutput\"R\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02#\"!/students/{member_id}/assignments\x12\xc8\x01\n\x17\x44\x65leteStudentAssignment\x12+.eolymp.course.DeleteStudentAssignmentInput\x1a,.eolymp.course.DeleteStudentAssignmentOutput\"R\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02#*!/students/{member_id}/assignments\x12\xb1\x01\n\x11ListStudentGrades\x12%.eolymp.course.ListStudentGradesInput\x1a&.eolymp.course.ListStudentGradesOutput\"M\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1e\x12\x1c/students/{member_id}/grades\x12\xba\x01\n\x10ListModuleGrades\x12$.eolymp.course.ListModuleGradesInput\x1a%.eolymp.course.ListModuleGradesOutput\"Y\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02*\x12(/students/{member_id}/grades/{module_id}B/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.student_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _STUDENTSERVICE.methods_by_name['CreateStudent']._options = None
  _STUDENTSERVICE.methods_by_name['CreateStudent']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\013\"\t/students'
  _STUDENTSERVICE.methods_by_name['UpdateStudent']._options = None
  _STUDENTSERVICE.methods_by_name['UpdateStudent']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\027\"\025/students/{member_id}'
  _STUDENTSERVICE.methods_by_name['DeleteStudent']._options = None
  _STUDENTSERVICE.methods_by_name['DeleteStudent']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\027*\025/students/{member_id}'
  _STUDENTSERVICE.methods_by_name['DescribeStudent']._options = None
  _STUDENTSERVICE.methods_by_name['DescribeStudent']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\027\022\025/students/{member_id}'
  _STUDENTSERVICE.methods_by_name['ListStudents']._options = None
  _STUDENTSERVICE.methods_by_name['ListStudents']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\013\022\t/students'
  _STUDENTSERVICE.methods_by_name['WatchStudent']._options = None
  _STUDENTSERVICE.methods_by_name['WatchStudent']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read'
  _STUDENTSERVICE.methods_by_name['JoinCourse']._options = None
  _STUDENTSERVICE.methods_by_name['JoinCourse']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\007\"\005/join'
  _STUDENTSERVICE.methods_by_name['DescribeViewer']._options = None
  _STUDENTSERVICE.methods_by_name['DescribeViewer']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\021\022\017/viewer/student'
  _STUDENTSERVICE.methods_by_name['ListStudentAssignments']._options = None
  _STUDENTSERVICE.methods_by_name['ListStudentAssignments']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002#\022!/students/{member_id}/assignments'
  _STUDENTSERVICE.methods_by_name['UpdateStudentAssignment']._options = None
  _STUDENTSERVICE.methods_by_name['UpdateStudentAssignment']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002#\"!/students/{member_id}/assignments'
  _STUDENTSERVICE.methods_by_name['DeleteStudentAssignment']._options = None
  _STUDENTSERVICE.methods_by_name['DeleteStudentAssignment']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002#*!/students/{member_id}/assignments'
  _STUDENTSERVICE.methods_by_name['ListStudentGrades']._options = None
  _STUDENTSERVICE.methods_by_name['ListStudentGrades']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\036\022\034/students/{member_id}/grades'
  _STUDENTSERVICE.methods_by_name['ListModuleGrades']._options = None
  _STUDENTSERVICE.methods_by_name['ListModuleGrades']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002*\022(/students/{member_id}/grades/{module_id}'
  _CREATESTUDENTINPUT._serialized_start=374
  _CREATESTUDENTINPUT._serialized_end=435
  _CREATESTUDENTOUTPUT._serialized_start=437
  _CREATESTUDENTOUTPUT._serialized_end=478
  _UPDATESTUDENTINPUT._serialized_start=481
  _UPDATESTUDENTINPUT._serialized_end=665
  _UPDATESTUDENTINPUT_PATCH._serialized_start=619
  _UPDATESTUDENTINPUT_PATCH._serialized_end=665
  _UPDATESTUDENTOUTPUT._serialized_start=667
  _UPDATESTUDENTOUTPUT._serialized_end=688
  _DELETESTUDENTINPUT._serialized_start=690
  _DELETESTUDENTINPUT._serialized_end=729
  _DELETESTUDENTOUTPUT._serialized_start=731
  _DELETESTUDENTOUTPUT._serialized_end=752
  _DESCRIBESTUDENTINPUT._serialized_start=754
  _DESCRIBESTUDENTINPUT._serialized_end=841
  _DESCRIBESTUDENTOUTPUT._serialized_start=843
  _DESCRIBESTUDENTOUTPUT._serialized_end=907
  _LISTSTUDENTSINPUT._serialized_start=910
  _LISTSTUDENTSINPUT._serialized_end=1375
  _LISTSTUDENTSINPUT_FILTER._serialized_start=1182
  _LISTSTUDENTSINPUT_FILTER._serialized_end=1350
  _LISTSTUDENTSINPUT_SORTABLE._serialized_start=1352
  _LISTSTUDENTSINPUT_SORTABLE._serialized_end=1375
  _LISTSTUDENTSOUTPUT._serialized_start=1377
  _LISTSTUDENTSOUTPUT._serialized_end=1503
  _WATCHSTUDENTINPUT._serialized_start=1505
  _WATCHSTUDENTINPUT._serialized_end=1589
  _WATCHSTUDENTOUTPUT._serialized_start=1591
  _WATCHSTUDENTOUTPUT._serialized_end=1652
  _JOINCOURSEINPUT._serialized_start=1654
  _JOINCOURSEINPUT._serialized_end=1671
  _JOINCOURSEOUTPUT._serialized_start=1673
  _JOINCOURSEOUTPUT._serialized_end=1691
  _DESCRIBEVIEWERINPUT._serialized_start=1693
  _DESCRIBEVIEWERINPUT._serialized_end=1760
  _DESCRIBEVIEWEROUTPUT._serialized_start=1762
  _DESCRIBEVIEWEROUTPUT._serialized_end=1825
  _LISTSTUDENTASSIGNMENTSINPUT._serialized_start=1828
  _LISTSTUDENTASSIGNMENTSINPUT._serialized_end=2094
  _LISTSTUDENTASSIGNMENTSINPUT_FILTER._serialized_start=1976
  _LISTSTUDENTASSIGNMENTSINPUT_FILTER._serialized_end=2094
  _LISTSTUDENTASSIGNMENTSOUTPUT._serialized_start=2096
  _LISTSTUDENTASSIGNMENTSOUTPUT._serialized_end=2183
  _UPDATESTUDENTASSIGNMENTINPUT._serialized_start=2186
  _UPDATESTUDENTASSIGNMENTINPUT._serialized_end=2391
  _UPDATESTUDENTASSIGNMENTOUTPUT._serialized_start=2393
  _UPDATESTUDENTASSIGNMENTOUTPUT._serialized_end=2424
  _DELETESTUDENTASSIGNMENTINPUT._serialized_start=2426
  _DELETESTUDENTASSIGNMENTINPUT._serialized_end=2494
  _DELETESTUDENTASSIGNMENTOUTPUT._serialized_start=2496
  _DELETESTUDENTASSIGNMENTOUTPUT._serialized_end=2527
  _LISTSTUDENTGRADESINPUT._serialized_start=2529
  _LISTSTUDENTGRADESINPUT._serialized_end=2572
  _LISTSTUDENTGRADESOUTPUT._serialized_start=2574
  _LISTSTUDENTGRADESOUTPUT._serialized_end=2646
  _LISTMODULEGRADESINPUT._serialized_start=2648
  _LISTMODULEGRADESINPUT._serialized_end=2709
  _LISTMODULEGRADESOUTPUT._serialized_start=2711
  _LISTMODULEGRADESOUTPUT._serialized_end=2784
  _STUDENTSERVICE._serialized_start=2787
  _STUDENTSERVICE._serialized_end=4974
# @@protoc_insertion_point(module_scope)



from eolymp.judge import medal_pb2 as _medal_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Scoreboard(_message.Message):
    __slots__ = ["columns", "modes", "rounds"]
    class Mode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Column(_message.Message):
        __slots__ = ["choices", "filterable", "id", "sortable", "title", "type"]
        class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = []
        CHECKBOX: Scoreboard.Column.Type
        CHOICE: Scoreboard.Column.Type
        CHOICES_FIELD_NUMBER: _ClassVar[int]
        COUNTRY: Scoreboard.Column.Type
        DATE: Scoreboard.Column.Type
        EMAIL: Scoreboard.Column.Type
        FILTERABLE_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        INSTITUTION: Scoreboard.Column.Type
        NUMBER: Scoreboard.Column.Type
        PROBLEM_SCORE: Scoreboard.Column.Type
        REGION: Scoreboard.Column.Type
        ROUND_SCORE: Scoreboard.Column.Type
        SORTABLE_FIELD_NUMBER: _ClassVar[int]
        STRING: Scoreboard.Column.Type
        TITLE_FIELD_NUMBER: _ClassVar[int]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        UNKNOWN_TYPE: Scoreboard.Column.Type
        choices: _containers.RepeatedScalarFieldContainer[str]
        filterable: bool
        id: str
        sortable: bool
        title: str
        type: Scoreboard.Column.Type
        def __init__(self, id: _Optional[str] = ..., type: _Optional[_Union[Scoreboard.Column.Type, str]] = ..., title: _Optional[str] = ..., choices: _Optional[_Iterable[str]] = ..., sortable: bool = ..., filterable: bool = ...) -> None: ...
    class Round(_message.Message):
        __slots__ = ["id", "title"]
        ID_FIELD_NUMBER: _ClassVar[int]
        TITLE_FIELD_NUMBER: _ClassVar[int]
        id: str
        title: str
        def __init__(self, id: _Optional[str] = ..., title: _Optional[str] = ...) -> None: ...
    class Row(_message.Message):
        __slots__ = ["disqualified", "id", "index", "medal", "member_id", "penalty", "rank", "rank_length", "score", "tie_breaker", "unofficial", "values"]
        class ProblemScore(_message.Message):
            __slots__ = ["attempts", "penalty", "percentage", "score", "time"]
            ATTEMPTS_FIELD_NUMBER: _ClassVar[int]
            PENALTY_FIELD_NUMBER: _ClassVar[int]
            PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
            SCORE_FIELD_NUMBER: _ClassVar[int]
            TIME_FIELD_NUMBER: _ClassVar[int]
            attempts: int
            penalty: float
            percentage: float
            score: float
            time: int
            def __init__(self, score: _Optional[float] = ..., penalty: _Optional[float] = ..., attempts: _Optional[int] = ..., percentage: _Optional[float] = ..., time: _Optional[int] = ...) -> None: ...
        class RoundScore(_message.Message):
            __slots__ = ["disqualified", "medal", "penalty", "score", "tie_breaker", "unofficial"]
            DISQUALIFIED_FIELD_NUMBER: _ClassVar[int]
            MEDAL_FIELD_NUMBER: _ClassVar[int]
            PENALTY_FIELD_NUMBER: _ClassVar[int]
            SCORE_FIELD_NUMBER: _ClassVar[int]
            TIE_BREAKER_FIELD_NUMBER: _ClassVar[int]
            UNOFFICIAL_FIELD_NUMBER: _ClassVar[int]
            disqualified: bool
            medal: _medal_pb2.Medal
            penalty: float
            score: float
            tie_breaker: int
            unofficial: bool
            def __init__(self, score: _Optional[float] = ..., penalty: _Optional[float] = ..., tie_breaker: _Optional[int] = ..., unofficial: bool = ..., disqualified: bool = ..., medal: _Optional[_Union[_medal_pb2.Medal, str]] = ...) -> None: ...
        class Value(_message.Message):
            __slots__ = ["column_id", "number", "problem_score", "round_score", "string"]
            COLUMN_ID_FIELD_NUMBER: _ClassVar[int]
            NUMBER_FIELD_NUMBER: _ClassVar[int]
            PROBLEM_SCORE_FIELD_NUMBER: _ClassVar[int]
            ROUND_SCORE_FIELD_NUMBER: _ClassVar[int]
            STRING_FIELD_NUMBER: _ClassVar[int]
            column_id: str
            number: str
            problem_score: Scoreboard.Row.ProblemScore
            round_score: Scoreboard.Row.RoundScore
            string: str
            def __init__(self, column_id: _Optional[str] = ..., round_score: _Optional[_Union[Scoreboard.Row.RoundScore, _Mapping]] = ..., problem_score: _Optional[_Union[Scoreboard.Row.ProblemScore, _Mapping]] = ..., string: _Optional[str] = ..., number: _Optional[str] = ...) -> None: ...
        DISQUALIFIED_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        INDEX_FIELD_NUMBER: _ClassVar[int]
        MEDAL_FIELD_NUMBER: _ClassVar[int]
        MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
        PENALTY_FIELD_NUMBER: _ClassVar[int]
        RANK_FIELD_NUMBER: _ClassVar[int]
        RANK_LENGTH_FIELD_NUMBER: _ClassVar[int]
        SCORE_FIELD_NUMBER: _ClassVar[int]
        TIE_BREAKER_FIELD_NUMBER: _ClassVar[int]
        UNOFFICIAL_FIELD_NUMBER: _ClassVar[int]
        VALUES_FIELD_NUMBER: _ClassVar[int]
        disqualified: bool
        id: str
        index: int
        medal: _medal_pb2.Medal
        member_id: str
        penalty: float
        rank: int
        rank_length: int
        score: float
        tie_breaker: int
        unofficial: bool
        values: _containers.RepeatedCompositeFieldContainer[Scoreboard.Row.Value]
        def __init__(self, id: _Optional[str] = ..., member_id: _Optional[str] = ..., index: _Optional[int] = ..., rank: _Optional[int] = ..., rank_length: _Optional[int] = ..., score: _Optional[float] = ..., penalty: _Optional[float] = ..., tie_breaker: _Optional[int] = ..., unofficial: bool = ..., disqualified: bool = ..., medal: _Optional[_Union[_medal_pb2.Medal, str]] = ..., values: _Optional[_Iterable[_Union[Scoreboard.Row.Value, _Mapping]]] = ...) -> None: ...
    COLUMNS_FIELD_NUMBER: _ClassVar[int]
    FROZEN: Scoreboard.Mode
    MODES_FIELD_NUMBER: _ClassVar[int]
    RESULT: Scoreboard.Mode
    ROUNDS_FIELD_NUMBER: _ClassVar[int]
    UPSOLVE: Scoreboard.Mode
    columns: _containers.RepeatedCompositeFieldContainer[Scoreboard.Column]
    modes: _containers.RepeatedScalarFieldContainer[Scoreboard.Mode]
    rounds: _containers.RepeatedCompositeFieldContainer[Scoreboard.Round]
    def __init__(self, modes: _Optional[_Iterable[_Union[Scoreboard.Mode, str]]] = ..., rounds: _Optional[_Iterable[_Union[Scoreboard.Round, _Mapping]]] = ..., columns: _Optional[_Iterable[_Union[Scoreboard.Column, _Mapping]]] = ...) -> None: ...



from eolymp.universe import space_pb2 as _space_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SpaceChangeRecord(_message.Message):
    __slots__ = ["op", "space"]
    class Operation(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    CREATE: SpaceChangeRecord.Operation
    DELETE: SpaceChangeRecord.Operation
    NO_OPERATION: SpaceChangeRecord.Operation
    OP_FIELD_NUMBER: _ClassVar[int]
    SOFT_DELETE: SpaceChangeRecord.Operation
    SPACE_FIELD_NUMBER: _ClassVar[int]
    UPDATE: SpaceChangeRecord.Operation
    op: SpaceChangeRecord.Operation
    space: _space_pb2.Space
    def __init__(self, op: _Optional[_Union[SpaceChangeRecord.Operation, str]] = ..., space: _Optional[_Union[_space_pb2.Space, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/universe/plan.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from eolymp.universe import quota_pb2 as eolymp_dot_universe_dot_quota__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/universe/plan.proto\x12\x0f\x65olymp.universe\x1a\x18\x65olymp/ecm/content.proto\x1a\x1b\x65olymp/universe/quota.proto\"\xf9\x03\n\x04Plan\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12(\n\x0b\x64\x65scription\x18\x03 \x01(\x0b\x32\x13.eolymp.ecm.Content\x12%\n\x05quota\x18\x04 \x01(\x0b\x32\x16.eolymp.universe.Quota\x12\x0e\n\x06labels\x18\x05 \x03(\t\x12\x19\n\x11requires_approval\x18\x07 \x01(\x08\x12\x11\n\tmin_seats\x18\n \x01(\r\x12\x11\n\tmax_seats\x18\x0b \x01(\r\x12/\n\x08variants\x18\x64 \x03(\x0b\x32\x1d.eolymp.universe.Plan.Variant\x1ar\n\x07Variant\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\nrecurrence\x18\x03 \x01(\x0e\x32 .eolymp.universe.Plan.Recurrence\x12\x10\n\x08\x63urrency\x18\x1e \x01(\t\x12\x13\n\x0bunit_amount\x18\x1f \x01(\x05\"D\n\x05\x45xtra\x12\x0c\n\x08NO_EXTRA\x10\x00\x12\x16\n\x12\x44\x45SCRIPTION_RENDER\x10\x01\x12\x15\n\x11\x44\x45SCRIPTION_VALUE\x10\x02\"J\n\nRecurrence\x12\x16\n\x12UNKNOWN_RECURRENCE\x10\x00\x12\x0b\n\x07ONETIME\x10\x01\x12\x0b\n\x07MONTHLY\x10\x02\x12\n\n\x06YEARLY\x10\x03\x42\x33Z1github.com/eolymp/go-sdk/eolymp/universe;universeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.universe.plan_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/universe;universe'
  _PLAN._serialized_start=103
  _PLAN._serialized_end=608
  _PLAN_VARIANT._serialized_start=348
  _PLAN_VARIANT._serialized_end=462
  _PLAN_EXTRA._serialized_start=464
  _PLAN_EXTRA._serialized_end=532
  _PLAN_RECURRENCE._serialized_start=534
  _PLAN_RECURRENCE._serialized_end=608
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Preferences(_message.Message):
    __slots__ = ["subscriptions"]
    class Digest(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Subscription(_message.Message):
        __slots__ = ["digest", "topic"]
        DIGEST_FIELD_NUMBER: _ClassVar[int]
        TOPIC_FIELD_NUMBER: _ClassVar[int]
        digest: Preferences.Digest
        topic: str
        def __init__(self, topic: _Optional[str] = ..., digest: _Optional[_Union[Preferences.Digest, str]] = ...) -> None: ...
    DAILY: Preferences.Digest
    HOURLY: Preferences.Digest
    IMMEDIATE: Preferences.Digest
    SUBSCRIPTIONS_FIELD_NUMBER: _ClassVar[int]
    UNKNOWN_DIGEST: Preferences.Digest
    subscriptions: _containers.RepeatedCompositeFieldContainer[Preferences.Subscription]
    def __init__(self, subscriptions: _Optional[_Iterable[_Union[Preferences.Subscription, _Mapping]]] = ...) -> None: ...



from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Newsletter(_message.Message):
    __slots__ = ["content", "created_at", "id", "subject"]
    class Translation(_message.Message):
        __slots__ = ["content", "id", "locale", "subject"]
        CONTENT_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        SUBJECT_FIELD_NUMBER: _ClassVar[int]
        content: _content_pb2.Content
        id: str
        locale: str
        subject: str
        def __init__(self, id: _Optional[str] = ..., locale: _Optional[str] = ..., subject: _Optional[str] = ..., content: _Optional[_Union[_content_pb2.Content, _Mapping]] = ...) -> None: ...
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    content: _content_pb2.Content
    created_at: _timestamp_pb2.Timestamp
    id: str
    subject: str
    def __init__(self, id: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., subject: _Optional[str] = ..., content: _Optional[_Union[_content_pb2.Content, _Mapping]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.mailing import email_type_pb2 as _email_type_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DescribeEmailSubscriptionInput(_message.Message):
    __slots__ = ["token"]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    token: str
    def __init__(self, token: _Optional[str] = ...) -> None: ...

class DescribeEmailSubscriptionOutput(_message.Message):
    __slots__ = ["subscriptions"]
    SUBSCRIPTIONS_FIELD_NUMBER: _ClassVar[int]
    subscriptions: _containers.RepeatedScalarFieldContainer[_email_type_pb2.EmailType]
    def __init__(self, subscriptions: _Optional[_Iterable[_Union[_email_type_pb2.EmailType, str]]] = ...) -> None: ...

class UpdateEmailSubscriptionInput(_message.Message):
    __slots__ = ["subscriptions", "token"]
    SUBSCRIPTIONS_FIELD_NUMBER: _ClassVar[int]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    subscriptions: _containers.RepeatedScalarFieldContainer[_email_type_pb2.EmailType]
    token: str
    def __init__(self, token: _Optional[str] = ..., subscriptions: _Optional[_Iterable[_Union[_email_type_pb2.EmailType, str]]] = ...) -> None: ...

class UpdateEmailSubscriptionOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class TestingConfig(_message.Message):
    __slots__ = ["run_count"]
    RUN_COUNT_FIELD_NUMBER: _ClassVar[int]
    run_count: int
    def __init__(self, run_count: _Optional[int] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DescribePermissionInput(_message.Message):
    __slots__ = ["user_id"]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    def __init__(self, user_id: _Optional[str] = ...) -> None: ...

class DescribePermissionOutput(_message.Message):
    __slots__ = ["permission"]
    PERMISSION_FIELD_NUMBER: _ClassVar[int]
    permission: Permission
    def __init__(self, permission: _Optional[_Union[Permission, _Mapping]] = ...) -> None: ...

class GrantPermissionInput(_message.Message):
    __slots__ = ["entitlements", "role", "user_id"]
    ENTITLEMENTS_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    entitlements: _containers.RepeatedScalarFieldContainer[str]
    role: str
    user_id: str
    def __init__(self, user_id: _Optional[str] = ..., role: _Optional[str] = ..., entitlements: _Optional[_Iterable[str]] = ...) -> None: ...

class GrantPermissionOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class IntrospectPermissionInput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class IntrospectPermissionOutput(_message.Message):
    __slots__ = ["permission"]
    PERMISSION_FIELD_NUMBER: _ClassVar[int]
    permission: Permission
    def __init__(self, permission: _Optional[_Union[Permission, _Mapping]] = ...) -> None: ...

class ListPermissionsInput(_message.Message):
    __slots__ = ["filters", "offset", "size"]
    class Filter(_message.Message):
        __slots__ = ["id", "role", "user_id"]
        ID_FIELD_NUMBER: _ClassVar[int]
        ROLE_FIELD_NUMBER: _ClassVar[int]
        USER_ID_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        role: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        user_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., user_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., role: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    filters: ListPermissionsInput.Filter
    offset: int
    size: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListPermissionsInput.Filter, _Mapping]] = ...) -> None: ...

class ListPermissionsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[Permission]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[Permission, _Mapping]]] = ...) -> None: ...

class Permission(_message.Message):
    __slots__ = ["entitlements", "id", "role", "user_id"]
    ENTITLEMENTS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    entitlements: _containers.RepeatedScalarFieldContainer[str]
    id: str
    role: str
    user_id: str
    def __init__(self, id: _Optional[str] = ..., role: _Optional[str] = ..., user_id: _Optional[str] = ..., entitlements: _Optional[_Iterable[str]] = ...) -> None: ...

class RevokePermissionInput(_message.Message):
    __slots__ = ["user_id"]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    def __init__(self, user_id: _Optional[str] = ...) -> None: ...

class RevokePermissionOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/executor/checker.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import file_pb2 as eolymp_dot_executor_dot_file__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/executor/checker.proto\x12\x0f\x65olymp.executor\x1a\x1a\x65olymp/executor/file.proto\"\xa2\x02\n\x07\x43hecker\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.eolymp.executor.Checker.Type\x12\x0f\n\x07runtime\x18\x02 \x01(\t\x12\x12\n\nsource_url\x18\x08 \x01(\t\x12\x11\n\tprecision\x18\x04 \x01(\x05\x12\x16\n\x0e\x63\x61se_sensitive\x18\x05 \x01(\x08\x12\x17\n\x0forder_sensitive\x18\x06 \x01(\x08\x12$\n\x05\x66iles\x18\n \x03(\x0b\x32\x15.eolymp.executor.File\"[\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06TOKENS\x10\x01\x12\t\n\x05LINES\x10\x02\x12\x0b\n\x07PROGRAM\x10\x03\x12\x12\n\x0eLEGACY_PROGRAM\x10\x04\x12\x11\n\rQUERY_RESULTS\x10\x05\x42\x33Z1github.com/eolymp/go-sdk/eolymp/executor;executorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.executor.checker_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/executor;executor'
  _CHECKER._serialized_start=79
  _CHECKER._serialized_end=369
  _CHECKER_TYPE._serialized_start=278
  _CHECKER_TYPE._serialized_end=369
# @@protoc_insertion_point(module_scope)



from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Announcement(_message.Message):
    __slots__ = ["contest_id", "created_at", "id", "message", "subject"]
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_RENDER: Announcement.Extra
    MESSAGE_VALUE: Announcement.Extra
    NO_EXTRA: Announcement.Extra
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    created_at: _timestamp_pb2.Timestamp
    id: str
    message: _content_pb2.Content
    subject: str
    def __init__(self, id: _Optional[str] = ..., contest_id: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., subject: _Optional[str] = ..., message: _Optional[_Union[_content_pb2.Content, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/script.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import file_pb2 as eolymp_dot_executor_dot_file__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x65olymp/atlas/script.proto\x12\x0c\x65olymp.atlas\x1a\x1a\x65olymp/executor/file.proto\"\x9c\x01\n\x06Script\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06secret\x18\x07 \x01(\x08\x12\x0f\n\x07runtime\x18\n \x01(\t\x12\x0e\n\x06source\x18\x0b \x01(\t\x12$\n\x05\x66iles\x18\x14 \x03(\x0b\x32\x15.eolymp.executor.File\"!\n\x05\x45xtra\x12\x0c\n\x08NO_EXTRA\x10\x00\x12\n\n\x06SOURCE\x10\x01\x42-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.script_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _SCRIPT._serialized_start=72
  _SCRIPT._serialized_end=228
  _SCRIPT_EXTRA._serialized_start=195
  _SCRIPT_EXTRA._serialized_end=228
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/configuration_identity.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.community import configuration_idp_pb2 as eolymp_dot_community_dot_configuration__idp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-eolymp/community/configuration_identity.proto\x12\x10\x65olymp.community\x1a(eolymp/community/configuration_idp.proto\"\xa9\x03\n\x0eIdentityConfig\x12\x39\n\x05local\x18\x01 \x01(\x0b\x32(.eolymp.community.IdentityProvider.LocalH\x00\x12?\n\x08\x62\x61secamp\x18\x02 \x01(\x0b\x32+.eolymp.community.IdentityProvider.BasecampH\x00\x12\x37\n\x04oidc\x18\x03 \x01(\x0b\x32\'.eolymp.community.IdentityProvider.OIDCH\x00\x12K\n\x11\x64isplay_name_type\x18\x64 \x01(\x0e\x32\x30.eolymp.community.IdentityConfig.DisplayNameType\x12\x1e\n\x16\x64isplay_name_attribute\x18\x65 \x01(\t\x12\x15\n\rallow_sign_up\x18\x66 \x01(\x08\"R\n\x0f\x44isplayNameType\x12\x18\n\x14UNKNOWN_DISPLAY_NAME\x10\x00\x12\x0c\n\x08NICKNAME\x10\x01\x12\x08\n\x04NAME\x10\x02\x12\r\n\tATTRIBUTE\x10\x03\x42\n\n\x08providerB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.configuration_identity_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _IDENTITYCONFIG._serialized_start=110
  _IDENTITYCONFIG._serialized_end=535
  _IDENTITYCONFIG_DISPLAYNAMETYPE._serialized_start=441
  _IDENTITYCONFIG_DISPLAYNAMETYPE._serialized_end=523
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/group_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.community import group_pb2 as eolymp_dot_community_dot_group__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/community/group_service.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1c\x65olymp/community/group.proto\x1a!eolymp/wellknown/expression.proto\":\n\x10\x43reateGroupInput\x12&\n\x05group\x18\x01 \x01(\x0b\x32\x17.eolymp.community.Group\"%\n\x11\x43reateGroupOutput\x12\x10\n\x08group_id\x18\x01 \x01(\t\"\xb2\x01\n\x10UpdateGroupInput\x12\x37\n\x05patch\x18\x01 \x03(\x0e\x32(.eolymp.community.UpdateGroupInput.Patch\x12\x10\n\x08group_id\x18\x02 \x01(\t\x12&\n\x05group\x18\x03 \x01(\x0b\x32\x17.eolymp.community.Group\"+\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x08\n\x04NAME\x10\x01\x12\x0f\n\x0b\x44\x45SCRIPTION\x10\x02\"\x13\n\x11UpdateGroupOutput\"$\n\x10\x44\x65leteGroupInput\x12\x10\n\x08group_id\x18\x01 \x01(\t\"\x13\n\x11\x44\x65leteGroupOutput\"&\n\x12\x44\x65scribeGroupInput\x12\x10\n\x08group_id\x18\x01 \x01(\t\"=\n\x13\x44\x65scribeGroupOutput\x12&\n\x05group\x18\x01 \x01(\x0b\x32\x17.eolymp.community.Group\"\xe1\x01\n\x0fListGroupsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x39\n\x07\x66ilters\x18( \x01(\x0b\x32(.eolymp.community.ListGroupsInput.Filter\x1au\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"I\n\x10ListGroupsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.community.Group2\x9e\x06\n\x0cGroupService\x12\x93\x01\n\x0b\x43reateGroup\x12\".eolymp.community.CreateGroupInput\x1a#.eolymp.community.CreateGroupOutput\";\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:group:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\t\"\x07/groups\x12\x9e\x01\n\x0bUpdateGroup\x12\".eolymp.community.UpdateGroupInput\x1a#.eolymp.community.UpdateGroupOutput\"F\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:group:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x14\"\x12/groups/{group_id}\x12\x9e\x01\n\x0b\x44\x65leteGroup\x12\".eolymp.community.DeleteGroupInput\x1a#.eolymp.community.DeleteGroupOutput\"F\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:group:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x14*\x12/groups/{group_id}\x12\xa3\x01\n\rDescribeGroup\x12$.eolymp.community.DescribeGroupInput\x1a%.eolymp.community.DescribeGroupOutput\"E\x82\xe3\n\x18\x8a\xe3\n\x14\x63ommunity:group:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x14\x12\x12/groups/{group_id}\x12\x8f\x01\n\nListGroups\x12!.eolymp.community.ListGroupsInput\x1a\".eolymp.community.ListGroupsOutput\":\x82\xe3\n\x18\x8a\xe3\n\x14\x63ommunity:group:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\t\x12\x07/groupsB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.group_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _GROUPSERVICE.methods_by_name['CreateGroup']._options = None
  _GROUPSERVICE.methods_by_name['CreateGroup']._serialized_options = b'\202\343\n\031\212\343\n\025community:group:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\t\"\007/groups'
  _GROUPSERVICE.methods_by_name['UpdateGroup']._options = None
  _GROUPSERVICE.methods_by_name['UpdateGroup']._serialized_options = b'\202\343\n\031\212\343\n\025community:group:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\024\"\022/groups/{group_id}'
  _GROUPSERVICE.methods_by_name['DeleteGroup']._options = None
  _GROUPSERVICE.methods_by_name['DeleteGroup']._serialized_options = b'\202\343\n\031\212\343\n\025community:group:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\024*\022/groups/{group_id}'
  _GROUPSERVICE.methods_by_name['DescribeGroup']._options = None
  _GROUPSERVICE.methods_by_name['DescribeGroup']._serialized_options = b'\202\343\n\030\212\343\n\024community:group:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\024\022\022/groups/{group_id}'
  _GROUPSERVICE.methods_by_name['ListGroups']._options = None
  _GROUPSERVICE.methods_by_name['ListGroups']._serialized_options = b'\202\343\n\030\212\343\n\024community:group:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\t\022\007/groups'
  _CREATEGROUPINPUT._serialized_start=222
  _CREATEGROUPINPUT._serialized_end=280
  _CREATEGROUPOUTPUT._serialized_start=282
  _CREATEGROUPOUTPUT._serialized_end=319
  _UPDATEGROUPINPUT._serialized_start=322
  _UPDATEGROUPINPUT._serialized_end=500
  _UPDATEGROUPINPUT_PATCH._serialized_start=457
  _UPDATEGROUPINPUT_PATCH._serialized_end=500
  _UPDATEGROUPOUTPUT._serialized_start=502
  _UPDATEGROUPOUTPUT._serialized_end=521
  _DELETEGROUPINPUT._serialized_start=523
  _DELETEGROUPINPUT._serialized_end=559
  _DELETEGROUPOUTPUT._serialized_start=561
  _DELETEGROUPOUTPUT._serialized_end=580
  _DESCRIBEGROUPINPUT._serialized_start=582
  _DESCRIBEGROUPINPUT._serialized_end=620
  _DESCRIBEGROUPOUTPUT._serialized_start=622
  _DESCRIBEGROUPOUTPUT._serialized_end=683
  _LISTGROUPSINPUT._serialized_start=686
  _LISTGROUPSINPUT._serialized_end=911
  _LISTGROUPSINPUT_FILTER._serialized_start=794
  _LISTGROUPSINPUT_FILTER._serialized_end=911
  _LISTGROUPSOUTPUT._serialized_start=913
  _LISTGROUPSOUTPUT._serialized_end=986
  _GROUPSERVICE._serialized_start=989
  _GROUPSERVICE._serialized_end=1787
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/editorial_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import editorial_pb2 as eolymp_dot_atlas_dot_editorial__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/atlas/editorial_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1c\x65olymp/atlas/editorial.proto\"6\n\x13ListEditorialsInput\x12\x0e\n\x06render\x18\x01 \x01(\x08\x12\x0f\n\x07version\x18\x64 \x01(\r\"M\n\x14ListEditorialsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.atlas.Editorial\"O\n\x16\x44\x65scribeEditorialInput\x12\x14\n\x0c\x65\x64itorial_id\x18\x02 \x01(\t\x12\x0e\n\x06render\x18\x03 \x01(\x08\x12\x0f\n\x07version\x18\x64 \x01(\r\"E\n\x17\x44\x65scribeEditorialOutput\x12*\n\teditorial\x18\x01 \x01(\x0b\x32\x17.eolymp.atlas.Editorial\"G\n\x14LookupEditorialInput\x12\x0e\n\x06locale\x18\x02 \x01(\t\x12\x0e\n\x06render\x18\x03 \x01(\x08\x12\x0f\n\x07version\x18\x64 \x01(\r\"C\n\x15LookupEditorialOutput\x12*\n\teditorial\x18\x01 \x01(\x0b\x32\x17.eolymp.atlas.Editorial\"C\n\x15PreviewEditorialInput\x12*\n\teditorial\x18\x02 \x01(\x0b\x32\x17.eolymp.atlas.Editorial\"D\n\x16PreviewEditorialOutput\x12*\n\teditorial\x18\x01 \x01(\x0b\x32\x17.eolymp.atlas.Editorial\"B\n\x14\x43reateEditorialInput\x12*\n\teditorial\x18\x02 \x01(\x0b\x32\x17.eolymp.atlas.Editorial\"-\n\x15\x43reateEditorialOutput\x12\x14\n\x0c\x65\x64itorial_id\x18\x01 \x01(\t\"\xcf\x01\n\x14UpdateEditorialInput\x12\x37\n\x05patch\x18\n \x03(\x0e\x32(.eolymp.atlas.UpdateEditorialInput.Patch\x12\x14\n\x0c\x65\x64itorial_id\x18\x02 \x01(\t\x12*\n\teditorial\x18\x03 \x01(\x0b\x32\x17.eolymp.atlas.Editorial\"<\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\n\n\x06LOCALE\x10\x01\x12\x0b\n\x07\x43ONTENT\x10\x02\x12\x11\n\rDOWNLOAD_LINK\x10\x03\"\x17\n\x15UpdateEditorialOutput\",\n\x14\x44\x65leteEditorialInput\x12\x14\n\x0c\x65\x64itorial_id\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteEditorialOutput2\x8b\t\n\x10\x45\x64itorialService\x12\x99\x01\n\x0f\x43reateEditorial\x12\".eolymp.atlas.CreateEditorialInput\x1a#.eolymp.atlas.CreateEditorialOutput\"=\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\r\x1a\x0b/editorials\x12\xa8\x01\n\x0fUpdateEditorial\x12\".eolymp.atlas.UpdateEditorialInput\x1a#.eolymp.atlas.UpdateEditorialOutput\"L\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1c\x1a\x1a/editorials/{editorial_id}\x12\xa8\x01\n\x0f\x44\x65leteEditorial\x12\".eolymp.atlas.DeleteEditorialInput\x1a#.eolymp.atlas.DeleteEditorialOutput\"L\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1c*\x1a/editorials/{editorial_id}\x12\xad\x01\n\x11\x44\x65scribeEditorial\x12$.eolymp.atlas.DescribeEditorialInput\x1a%.eolymp.atlas.DescribeEditorialOutput\"K\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1c\x12\x1a/editorials/{editorial_id}\x12\x97\x01\n\x0fLookupEditorial\x12\".eolymp.atlas.LookupEditorialInput\x1a#.eolymp.atlas.LookupEditorialOutput\";\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0c\x12\n/editorial\x12\xa2\x01\n\x10PreviewEditorial\x12#.eolymp.atlas.PreviewEditorialInput\x1a$.eolymp.atlas.PreviewEditorialOutput\"C\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x14\"\x12/editorial/preview\x12\x95\x01\n\x0eListEditorials\x12!.eolymp.atlas.ListEditorialsInput\x1a\".eolymp.atlas.ListEditorialsOutput\"<\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\r\x12\x0b/editorialsB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.editorial_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _EDITORIALSERVICE.methods_by_name['CreateEditorial']._options = None
  _EDITORIALSERVICE.methods_by_name['CreateEditorial']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\r\032\013/editorials'
  _EDITORIALSERVICE.methods_by_name['UpdateEditorial']._options = None
  _EDITORIALSERVICE.methods_by_name['UpdateEditorial']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\034\032\032/editorials/{editorial_id}'
  _EDITORIALSERVICE.methods_by_name['DeleteEditorial']._options = None
  _EDITORIALSERVICE.methods_by_name['DeleteEditorial']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\034*\032/editorials/{editorial_id}'
  _EDITORIALSERVICE.methods_by_name['DescribeEditorial']._options = None
  _EDITORIALSERVICE.methods_by_name['DescribeEditorial']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\034\022\032/editorials/{editorial_id}'
  _EDITORIALSERVICE.methods_by_name['LookupEditorial']._options = None
  _EDITORIALSERVICE.methods_by_name['LookupEditorial']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\014\022\n/editorial'
  _EDITORIALSERVICE.methods_by_name['PreviewEditorial']._options = None
  _EDITORIALSERVICE.methods_by_name['PreviewEditorial']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\024\"\022/editorial/preview'
  _EDITORIALSERVICE.methods_by_name['ListEditorials']._options = None
  _EDITORIALSERVICE.methods_by_name['ListEditorials']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\r\022\013/editorials'
  _LISTEDITORIALSINPUT._serialized_start=183
  _LISTEDITORIALSINPUT._serialized_end=237
  _LISTEDITORIALSOUTPUT._serialized_start=239
  _LISTEDITORIALSOUTPUT._serialized_end=316
  _DESCRIBEEDITORIALINPUT._serialized_start=318
  _DESCRIBEEDITORIALINPUT._serialized_end=397
  _DESCRIBEEDITORIALOUTPUT._serialized_start=399
  _DESCRIBEEDITORIALOUTPUT._serialized_end=468
  _LOOKUPEDITORIALINPUT._serialized_start=470
  _LOOKUPEDITORIALINPUT._serialized_end=541
  _LOOKUPEDITORIALOUTPUT._serialized_start=543
  _LOOKUPEDITORIALOUTPUT._serialized_end=610
  _PREVIEWEDITORIALINPUT._serialized_start=612
  _PREVIEWEDITORIALINPUT._serialized_end=679
  _PREVIEWEDITORIALOUTPUT._serialized_start=681
  _PREVIEWEDITORIALOUTPUT._serialized_end=749
  _CREATEEDITORIALINPUT._serialized_start=751
  _CREATEEDITORIALINPUT._serialized_end=817
  _CREATEEDITORIALOUTPUT._serialized_start=819
  _CREATEEDITORIALOUTPUT._serialized_end=864
  _UPDATEEDITORIALINPUT._serialized_start=867
  _UPDATEEDITORIALINPUT._serialized_end=1074
  _UPDATEEDITORIALINPUT_PATCH._serialized_start=1014
  _UPDATEEDITORIALINPUT_PATCH._serialized_end=1074
  _UPDATEEDITORIALOUTPUT._serialized_start=1076
  _UPDATEEDITORIALOUTPUT._serialized_end=1099
  _DELETEEDITORIALINPUT._serialized_start=1101
  _DELETEEDITORIALINPUT._serialized_end=1145
  _DELETEEDITORIALOUTPUT._serialized_start=1147
  _DELETEEDITORIALOUTPUT._serialized_end=1170
  _EDITORIALSERVICE._serialized_start=1173
  _EDITORIALSERVICE._serialized_end=2336
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class EnterPasscodeInput(_message.Message):
    __slots__ = ["contest_id", "passcode"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    PASSCODE_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    passcode: str
    def __init__(self, contest_id: _Optional[str] = ..., passcode: _Optional[str] = ...) -> None: ...

class EnterPasscodeOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class RemovePasscodeInput(_message.Message):
    __slots__ = ["contest_id", "participant_id"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    participant_id: str
    def __init__(self, contest_id: _Optional[str] = ..., participant_id: _Optional[str] = ...) -> None: ...

class RemovePasscodeOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ResetPasscodeInput(_message.Message):
    __slots__ = ["contest_id", "participant_id"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    participant_id: str
    def __init__(self, contest_id: _Optional[str] = ..., participant_id: _Optional[str] = ...) -> None: ...

class ResetPasscodeOutput(_message.Message):
    __slots__ = ["passcode"]
    PASSCODE_FIELD_NUMBER: _ClassVar[int]
    passcode: str
    def __init__(self, passcode: _Optional[str] = ...) -> None: ...

class SetPasscodeInput(_message.Message):
    __slots__ = ["contest_id", "participant_id", "passcode"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    PASSCODE_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    participant_id: str
    passcode: str
    def __init__(self, contest_id: _Optional[str] = ..., participant_id: _Optional[str] = ..., passcode: _Optional[str] = ...) -> None: ...

class SetPasscodeOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class VerifyPasscodeInput(_message.Message):
    __slots__ = ["contest_id"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    def __init__(self, contest_id: _Optional[str] = ...) -> None: ...

class VerifyPasscodeOutput(_message.Message):
    __slots__ = ["required", "valid"]
    REQUIRED_FIELD_NUMBER: _ClassVar[int]
    VALID_FIELD_NUMBER: _ClassVar[int]
    required: bool
    valid: bool
    def __init__(self, required: bool = ..., valid: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/testing_testset.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.atlas import testing_feedback_pb2 as eolymp_dot_atlas_dot_testing__feedback__pb2
from eolymp.atlas import testing_scoring_pb2 as eolymp_dot_atlas_dot_testing__scoring__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/atlas/testing_testset.proto\x12\x0c\x65olymp.atlas\x1a#eolymp/atlas/testing_feedback.proto\x1a\"eolymp/atlas/testing_scoring.proto\"\xf8\x01\n\x07Testset\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\r\x12\x12\n\ntime_limit\x18\n \x01(\r\x12\x11\n\tcpu_limit\x18\r \x01(\r\x12\x14\n\x0cmemory_limit\x18\x0b \x01(\x04\x12\x17\n\x0f\x66ile_size_limit\x18\x0c \x01(\x04\x12\x14\n\x0c\x64\x65pendencies\x18\x14 \x03(\r\x12/\n\x0cscoring_mode\x18\x1e \x01(\x0e\x32\x19.eolymp.atlas.ScoringMode\x12\x35\n\x0f\x66\x65\x65\x64\x62\x61\x63k_policy\x18( \x01(\x0e\x32\x1c.eolymp.atlas.FeedbackPolicyB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.testing_testset_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _TESTSET._serialized_start=126
  _TESTSET._serialized_end=374
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/linked_account.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%eolymp/community/linked_account.proto\x12\x10\x65olymp.community\"\x96\x01\n\rLinkedAccount\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x04type\x18\x02 \x01(\x0e\x32$.eolymp.community.LinkedAccount.Type\x12\x0e\n\x06issuer\x18\x03 \x01(\t\x12\x0f\n\x07subject\x18\x04 \x01(\t\"$\n\x04Type\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\n\n\x06GOOGLE\x10\x01\x42\x35Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.linked_account_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _LINKEDACCOUNT._serialized_start=60
  _LINKEDACCOUNT._serialized_end=210
  _LINKEDACCOUNT_TYPE._serialized_start=174
  _LINKEDACCOUNT_TYPE._serialized_end=210
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/ecm/node.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x65olymp/ecm/node.proto\x12\neolymp.ecm\"\x8f\x01\n\x04Node\x12\x0c\n\x04type\x18\x01 \x01(\t\x12(\n\x04\x61ttr\x18\x02 \x03(\x0b\x32\x1a.eolymp.ecm.Node.AttrEntry\x12\"\n\x08\x63hildren\x18\x03 \x03(\x0b\x32\x10.eolymp.ecm.Node\x1a+\n\tAttrEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42)Z\'github.com/eolymp/go-sdk/eolymp/ecm;ecmb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.ecm.node_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\'github.com/eolymp/go-sdk/eolymp/ecm;ecm'
  _NODE_ATTRENTRY._options = None
  _NODE_ATTRENTRY._serialized_options = b'8\001'
  _NODE._serialized_start=38
  _NODE._serialized_end=181
  _NODE_ATTRENTRY._serialized_start=138
  _NODE_ATTRENTRY._serialized_end=181
# @@protoc_insertion_point(module_scope)



from eolymp.executor import script_pb2 as _script_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenerationTask(_message.Message):
    __slots__ = ["origin", "reference", "runs", "scripts", "task_id"]
    class Generator(_message.Message):
        __slots__ = ["arguments", "script_name"]
        ARGUMENTS_FIELD_NUMBER: _ClassVar[int]
        SCRIPT_NAME_FIELD_NUMBER: _ClassVar[int]
        arguments: _containers.RepeatedScalarFieldContainer[str]
        script_name: str
        def __init__(self, script_name: _Optional[str] = ..., arguments: _Optional[_Iterable[str]] = ...) -> None: ...
    class Run(_message.Message):
        __slots__ = ["answer_content", "answer_generator", "answer_url", "input_content", "input_generator", "input_url", "reference"]
        ANSWER_CONTENT_FIELD_NUMBER: _ClassVar[int]
        ANSWER_GENERATOR_FIELD_NUMBER: _ClassVar[int]
        ANSWER_URL_FIELD_NUMBER: _ClassVar[int]
        INPUT_CONTENT_FIELD_NUMBER: _ClassVar[int]
        INPUT_GENERATOR_FIELD_NUMBER: _ClassVar[int]
        INPUT_URL_FIELD_NUMBER: _ClassVar[int]
        REFERENCE_FIELD_NUMBER: _ClassVar[int]
        answer_content: str
        answer_generator: GenerationTask.Generator
        answer_url: str
        input_content: str
        input_generator: GenerationTask.Generator
        input_url: str
        reference: str
        def __init__(self, reference: _Optional[str] = ..., input_url: _Optional[str] = ..., input_content: _Optional[str] = ..., input_generator: _Optional[_Union[GenerationTask.Generator, _Mapping]] = ..., answer_url: _Optional[str] = ..., answer_content: _Optional[str] = ..., answer_generator: _Optional[_Union[GenerationTask.Generator, _Mapping]] = ...) -> None: ...
    ORIGIN_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_FIELD_NUMBER: _ClassVar[int]
    RUNS_FIELD_NUMBER: _ClassVar[int]
    SCRIPTS_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    origin: str
    reference: str
    runs: _containers.RepeatedCompositeFieldContainer[GenerationTask.Run]
    scripts: _containers.RepeatedCompositeFieldContainer[_script_pb2.Script]
    task_id: str
    def __init__(self, task_id: _Optional[str] = ..., reference: _Optional[str] = ..., origin: _Optional[str] = ..., runs: _Optional[_Iterable[_Union[GenerationTask.Run, _Mapping]]] = ..., scripts: _Optional[_Iterable[_Union[_script_pb2.Script, _Mapping]]] = ...) -> None: ...



from .policy_pb2 import *
from .entitlement_service_pb2 import *
from .acl_service_http import *
from .acl_service_pb2 import *
from .entitlement_service_http import *
from .action_pb2 import *
from .policy_service_pb2 import *
from .permission_service_pb2 import *
from .permission_service_http import *
from .policy_service_http import *
from .events_pb2 import *



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.ecm import content_pb2 as _content_pb2
from eolymp.judge import ticket_pb2 as _ticket_pb2
from eolymp.judge import ticket_reply_pb2 as _ticket_reply_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateTicketInput(_message.Message):
    __slots__ = ["contest_id", "message", "raw_message", "subject"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    RAW_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    message: _content_pb2.Content
    raw_message: str
    subject: str
    def __init__(self, contest_id: _Optional[str] = ..., subject: _Optional[str] = ..., message: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., raw_message: _Optional[str] = ...) -> None: ...

class CreateTicketOutput(_message.Message):
    __slots__ = ["ticket_id"]
    TICKET_ID_FIELD_NUMBER: _ClassVar[int]
    ticket_id: str
    def __init__(self, ticket_id: _Optional[str] = ...) -> None: ...

class DeleteReplyInput(_message.Message):
    __slots__ = ["reply_id", "ticket_id"]
    REPLY_ID_FIELD_NUMBER: _ClassVar[int]
    TICKET_ID_FIELD_NUMBER: _ClassVar[int]
    reply_id: str
    ticket_id: str
    def __init__(self, ticket_id: _Optional[str] = ..., reply_id: _Optional[str] = ...) -> None: ...

class DeleteReplyOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteTicketInput(_message.Message):
    __slots__ = ["contest_id", "ticket_id"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    TICKET_ID_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    ticket_id: str
    def __init__(self, contest_id: _Optional[str] = ..., ticket_id: _Optional[str] = ...) -> None: ...

class DeleteTicketOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeReplyInput(_message.Message):
    __slots__ = ["extra", "reply_id", "ticket_id"]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    REPLY_ID_FIELD_NUMBER: _ClassVar[int]
    TICKET_ID_FIELD_NUMBER: _ClassVar[int]
    extra: _containers.RepeatedScalarFieldContainer[_ticket_reply_pb2.Reply.Extra]
    reply_id: str
    ticket_id: str
    def __init__(self, ticket_id: _Optional[str] = ..., reply_id: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_ticket_reply_pb2.Reply.Extra, str]]] = ...) -> None: ...

class DescribeReplyOutput(_message.Message):
    __slots__ = ["reply"]
    REPLY_FIELD_NUMBER: _ClassVar[int]
    reply: _ticket_reply_pb2.Reply
    def __init__(self, reply: _Optional[_Union[_ticket_reply_pb2.Reply, _Mapping]] = ...) -> None: ...

class DescribeTicketInput(_message.Message):
    __slots__ = ["contest_id", "extra", "ticket_id"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    TICKET_ID_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    extra: _containers.RepeatedScalarFieldContainer[_ticket_pb2.Ticket.Extra]
    ticket_id: str
    def __init__(self, contest_id: _Optional[str] = ..., ticket_id: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_ticket_pb2.Ticket.Extra, str]]] = ...) -> None: ...

class DescribeTicketOutput(_message.Message):
    __slots__ = ["ticket"]
    TICKET_FIELD_NUMBER: _ClassVar[int]
    ticket: _ticket_pb2.Ticket
    def __init__(self, ticket: _Optional[_Union[_ticket_pb2.Ticket, _Mapping]] = ...) -> None: ...

class ListRepliesInput(_message.Message):
    __slots__ = ["extra", "offset", "size", "ticket_id"]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    TICKET_ID_FIELD_NUMBER: _ClassVar[int]
    extra: _containers.RepeatedScalarFieldContainer[_ticket_reply_pb2.Reply.Extra]
    offset: int
    size: int
    ticket_id: str
    def __init__(self, ticket_id: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., extra: _Optional[_Iterable[_Union[_ticket_reply_pb2.Reply.Extra, str]]] = ...) -> None: ...

class ListRepliesOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_ticket_reply_pb2.Reply]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_ticket_reply_pb2.Reply, _Mapping]]] = ...) -> None: ...

class ListTicketsInput(_message.Message):
    __slots__ = ["after", "extra", "filters", "offset", "order", "size", "sort"]
    class Sort(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Filter(_message.Message):
        __slots__ = ["contest_id", "id", "is_open", "is_read", "member_id", "own", "participant_id", "status"]
        CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        IS_OPEN_FIELD_NUMBER: _ClassVar[int]
        IS_READ_FIELD_NUMBER: _ClassVar[int]
        MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
        OWN_FIELD_NUMBER: _ClassVar[int]
        PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        contest_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        is_open: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        is_read: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        member_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        own: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        participant_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        status: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., contest_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., participant_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., member_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., is_read: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., is_open: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., own: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., status: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    AFTER_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT: ListTicketsInput.Sort
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT: ListTicketsInput.Sort
    after: str
    extra: _containers.RepeatedScalarFieldContainer[_ticket_pb2.Ticket.Extra]
    filters: ListTicketsInput.Filter
    offset: int
    order: _direction_pb2.Direction
    size: int
    sort: ListTicketsInput.Sort
    def __init__(self, after: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListTicketsInput.Filter, _Mapping]] = ..., sort: _Optional[_Union[ListTicketsInput.Sort, str]] = ..., order: _Optional[_Union[_direction_pb2.Direction, str]] = ..., extra: _Optional[_Iterable[_Union[_ticket_pb2.Ticket.Extra, str]]] = ...) -> None: ...

class ListTicketsOutput(_message.Message):
    __slots__ = ["items", "next_page_cursor", "prev_page_cursor", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_CURSOR_FIELD_NUMBER: _ClassVar[int]
    PREV_PAGE_CURSOR_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_ticket_pb2.Ticket]
    next_page_cursor: str
    prev_page_cursor: str
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_ticket_pb2.Ticket, _Mapping]]] = ..., next_page_cursor: _Optional[str] = ..., prev_page_cursor: _Optional[str] = ...) -> None: ...

class ReadTicketInput(_message.Message):
    __slots__ = ["contest_id", "ticket_id", "timestamp"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    TICKET_ID_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    ticket_id: str
    timestamp: _timestamp_pb2.Timestamp
    def __init__(self, contest_id: _Optional[str] = ..., ticket_id: _Optional[str] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class ReadTicketOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ReplyChangedEvent(_message.Message):
    __slots__ = ["after", "before", "ticket_id"]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    TICKET_ID_FIELD_NUMBER: _ClassVar[int]
    after: _ticket_reply_pb2.Reply
    before: _ticket_reply_pb2.Reply
    ticket_id: str
    def __init__(self, ticket_id: _Optional[str] = ..., before: _Optional[_Union[_ticket_reply_pb2.Reply, _Mapping]] = ..., after: _Optional[_Union[_ticket_reply_pb2.Reply, _Mapping]] = ...) -> None: ...

class ReplyTicketInput(_message.Message):
    __slots__ = ["change_status_to", "message", "ticket_id"]
    CHANGE_STATUS_TO_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    TICKET_ID_FIELD_NUMBER: _ClassVar[int]
    change_status_to: _ticket_pb2.Ticket.Status
    message: _content_pb2.Content
    ticket_id: str
    def __init__(self, ticket_id: _Optional[str] = ..., message: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., change_status_to: _Optional[_Union[_ticket_pb2.Ticket.Status, str]] = ...) -> None: ...

class ReplyTicketOutput(_message.Message):
    __slots__ = ["reply_id"]
    REPLY_ID_FIELD_NUMBER: _ClassVar[int]
    reply_id: str
    def __init__(self, reply_id: _Optional[str] = ...) -> None: ...

class TicketChangedEvent(_message.Message):
    __slots__ = ["after", "before"]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    after: _ticket_pb2.Ticket
    before: _ticket_pb2.Ticket
    def __init__(self, before: _Optional[_Union[_ticket_pb2.Ticket, _Mapping]] = ..., after: _Optional[_Union[_ticket_pb2.Ticket, _Mapping]] = ...) -> None: ...

class UpdateReplyInput(_message.Message):
    __slots__ = ["message", "reply_id", "ticket_id"]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    REPLY_ID_FIELD_NUMBER: _ClassVar[int]
    TICKET_ID_FIELD_NUMBER: _ClassVar[int]
    message: _content_pb2.Content
    reply_id: str
    ticket_id: str
    def __init__(self, ticket_id: _Optional[str] = ..., reply_id: _Optional[str] = ..., message: _Optional[_Union[_content_pb2.Content, _Mapping]] = ...) -> None: ...

class UpdateReplyOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateTicketInput(_message.Message):
    __slots__ = ["patch", "ticket", "ticket_id"]
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ALL: UpdateTicketInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    STATUS: UpdateTicketInput.Patch
    SUBJECT: UpdateTicketInput.Patch
    TICKET_FIELD_NUMBER: _ClassVar[int]
    TICKET_ID_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[UpdateTicketInput.Patch]
    ticket: _ticket_pb2.Ticket
    ticket_id: str
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateTicketInput.Patch, str]]] = ..., ticket_id: _Optional[str] = ..., ticket: _Optional[_Union[_ticket_pb2.Ticket, _Mapping]] = ...) -> None: ...

class UpdateTicketOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class WatchRepliesInput(_message.Message):
    __slots__ = ["cursor", "extra", "ticket_id"]
    CURSOR_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    TICKET_ID_FIELD_NUMBER: _ClassVar[int]
    cursor: str
    extra: _containers.RepeatedScalarFieldContainer[_ticket_reply_pb2.Reply.Extra]
    ticket_id: str
    def __init__(self, ticket_id: _Optional[str] = ..., cursor: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_ticket_reply_pb2.Reply.Extra, str]]] = ...) -> None: ...

class WatchRepliesOutput(_message.Message):
    __slots__ = ["event", "reply"]
    class Event(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    CREATED: WatchRepliesOutput.Event
    DELETED: WatchRepliesOutput.Event
    EVENT_FIELD_NUMBER: _ClassVar[int]
    REPLY_FIELD_NUMBER: _ClassVar[int]
    UNKNOWN_EVENT: WatchRepliesOutput.Event
    UPDATED: WatchRepliesOutput.Event
    event: WatchRepliesOutput.Event
    reply: _ticket_reply_pb2.Reply
    def __init__(self, event: _Optional[_Union[WatchRepliesOutput.Event, str]] = ..., reply: _Optional[_Union[_ticket_reply_pb2.Reply, _Mapping]] = ...) -> None: ...

class WatchTicketInput(_message.Message):
    __slots__ = ["extra", "ticket_id"]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    TICKET_ID_FIELD_NUMBER: _ClassVar[int]
    extra: _containers.RepeatedScalarFieldContainer[_ticket_pb2.Ticket.Extra]
    ticket_id: str
    def __init__(self, ticket_id: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_ticket_pb2.Ticket.Extra, str]]] = ...) -> None: ...

class WatchTicketOutput(_message.Message):
    __slots__ = ["ticket"]
    TICKET_FIELD_NUMBER: _ClassVar[int]
    ticket: _ticket_pb2.Ticket
    def __init__(self, ticket: _Optional[_Union[_ticket_pb2.Ticket, _Mapping]] = ...) -> None: ...

class WatchTicketSummaryInput(_message.Message):
    __slots__ = ["contest_id", "member_id"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    member_id: str
    def __init__(self, contest_id: _Optional[str] = ..., member_id: _Optional[str] = ...) -> None: ...

class WatchTicketSummaryOutput(_message.Message):
    __slots__ = ["unread_count", "unresolved_count"]
    UNREAD_COUNT_FIELD_NUMBER: _ClassVar[int]
    UNRESOLVED_COUNT_FIELD_NUMBER: _ClassVar[int]
    unread_count: int
    unresolved_count: int
    def __init__(self, unread_count: _Optional[int] = ..., unresolved_count: _Optional[int] = ...) -> None: ...

class WatchTicketsInput(_message.Message):
    __slots__ = ["contest_id", "extra", "member_id", "status"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    extra: _containers.RepeatedScalarFieldContainer[_ticket_pb2.Ticket.Extra]
    member_id: str
    status: str
    def __init__(self, contest_id: _Optional[str] = ..., member_id: _Optional[str] = ..., status: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_ticket_pb2.Ticket.Extra, str]]] = ...) -> None: ...

class WatchTicketsOutput(_message.Message):
    __slots__ = ["event", "ticket"]
    class Event(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    CREATED: WatchTicketsOutput.Event
    DELETED: WatchTicketsOutput.Event
    EVENT_FIELD_NUMBER: _ClassVar[int]
    TICKET_FIELD_NUMBER: _ClassVar[int]
    UNKNOWN_EVENT: WatchTicketsOutput.Event
    UPDATED: WatchTicketsOutput.Event
    event: WatchTicketsOutput.Event
    ticket: _ticket_pb2.Ticket
    def __init__(self, event: _Optional[_Union[WatchTicketsOutput.Event, str]] = ..., ticket: _Optional[_Union[_ticket_pb2.Ticket, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/taxonomy/institution_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.taxonomy import institution_pb2 as eolymp_dot_taxonomy_dot_institution__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)eolymp/taxonomy/institution_service.proto\x12\x0f\x65olymp.taxonomy\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a!eolymp/taxonomy/institution.proto\x1a!eolymp/wellknown/expression.proto\"2\n\x18\x44\x65scribeInstitutionInput\x12\x16\n\x0einstitution_id\x18\x01 \x01(\t\"N\n\x19\x44\x65scribeInstitutionOutput\x12\x31\n\x0binstitution\x18\x01 \x01(\x0b\x32\x1c.eolymp.taxonomy.Institution\"\xa0\x04\n\x15ListInstitutionsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12>\n\x07\x66ilters\x18( \x01(\x0b\x32-.eolymp.taxonomy.ListInstitutionsInput.Filter\x1a\xa8\x03\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x33\n\x07\x61\x63ronym\x18\t \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x32\n\ncountry_id\x18\x04 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tregion_id\x18\x05 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x05level\x18\x06 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12.\n\x04type\x18\x07 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x34\n\ngovernance\x18\x08 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"T\n\x16ListInstitutionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12+\n\x05items\x18\x02 \x03(\x0b\x32\x1c.eolymp.taxonomy.Institution2\xc6\x02\n\x12InstitutionService\x12\x89\x01\n\x10ListInstitutions\x12&.eolymp.taxonomy.ListInstitutionsInput\x1a\'.eolymp.taxonomy.ListInstitutionsOutput\"$\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x0f\x12\r/institutions\x12\xa3\x01\n\x13\x44\x65scribeInstitution\x12).eolymp.taxonomy.DescribeInstitutionInput\x1a*.eolymp.taxonomy.DescribeInstitutionOutput\"5\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02 \x12\x1e/institutions/{institution_id}B3Z1github.com/eolymp/go-sdk/eolymp/taxonomy;taxonomyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.taxonomy.institution_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/taxonomy;taxonomy'
  _INSTITUTIONSERVICE.methods_by_name['ListInstitutions']._options = None
  _INSTITUTIONSERVICE.methods_by_name['ListInstitutions']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\017\022\r/institutions'
  _INSTITUTIONSERVICE.methods_by_name['DescribeInstitution']._options = None
  _INSTITUTIONSERVICE.methods_by_name['DescribeInstitution']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002 \022\036/institutions/{institution_id}'
  _DESCRIBEINSTITUTIONINPUT._serialized_start=199
  _DESCRIBEINSTITUTIONINPUT._serialized_end=249
  _DESCRIBEINSTITUTIONOUTPUT._serialized_start=251
  _DESCRIBEINSTITUTIONOUTPUT._serialized_end=329
  _LISTINSTITUTIONSINPUT._serialized_start=332
  _LISTINSTITUTIONSINPUT._serialized_end=876
  _LISTINSTITUTIONSINPUT_FILTER._serialized_start=452
  _LISTINSTITUTIONSINPUT_FILTER._serialized_end=876
  _LISTINSTITUTIONSOUTPUT._serialized_start=878
  _LISTINSTITUTIONSOUTPUT._serialized_end=962
  _INSTITUTIONSERVICE._serialized_start=965
  _INSTITUTIONSERVICE._serialized_end=1291
# @@protoc_insertion_point(module_scope)
